@@ -4,20 +4,20 @@
 #include <QObject>
 
 #include <mbarcode-qt/plugininterfaces.h>
-#include <mbarcode-qt/sinkplugin.h>
+#include <mbarcode-qt/pluginaction.h>
 
-class SinkPlugin;
+class PluginAction;
 class ISBNSink;
-class MainWindow;
+class MaemoBarcodeWindow;
 
 class ISBNPlugin : public QObject, public PluginInterface
 {
     Q_OBJECT
     Q_INTERFACES(PluginInterface)
 public:
-    void initInterface(MainWindow *parent);
+    void initInterface(QWidget *parent);
 
-    QSet<SinkPlugin*> getSinkPlugins();
+    QSet<PluginAction*> getPluginActions();
     QString getName() { return "ISBN opener"; }
 
 private:
@@ -25,7 +25,7 @@ private:
     ISBNSink *sink;
 };
 
-class ISBNSink : public QObject, public SinkPlugin
+class ISBNSink : public QObject, public PluginAction
 {
     Q_OBJECT
 public:
